@@ -53,7 +53,6 @@ ggdotplotstats <- function(data,
                            xlab = NULL,
                            ylab = NULL,
                            title = NULL,
-                           stat.title = NULL,
                            subtitle = NULL,
                            caption = NULL,
                            type = "parametric",
@@ -61,7 +60,6 @@ ggdotplotstats <- function(data,
                            bf.prior = 0.707,
                            bf.message = TRUE,
                            effsize.type = "g",
-                           effsize.noncentral = TRUE,
                            conf.level = 0.95,
                            nboot = 100,
                            k = 2,
@@ -83,7 +81,7 @@ ggdotplotstats <- function(data,
                            ...) {
 
   # convert entered stats type to a standard notation
-  type <- stats_type_switch(type)
+  type <- ipmisc::stats_type_switch(type)
 
   # ------------------------------ variable names ----------------------------
 
@@ -140,12 +138,10 @@ ggdotplotstats <- function(data,
         bf.prior = bf.prior,
         robust.estimator = "onestep",
         effsize.type = effsize.type,
-        effsize.noncentral = effsize.noncentral,
         conf.type = "norm",
         conf.level = conf.level,
         nboot = nboot,
         k = k,
-        stat.title = stat.title,
         messages = messages
       )
   }
