@@ -5,43 +5,59 @@ testthat::test_that(
   desc = "cor.vars works with different methods of inputs",
   code = {
     testthat::skip_on_cran()
-    set.seed(123)
 
     # method 1
-    df1 <- ggstatsplot::ggcorrmat(
-      data = ggplot2::msleep,
-      cor.vars = "sleep_total":"bodywt",
-      p.adjust.method = "BH",
-      output = "ci"
-    )
+    set.seed(123)
+    df1 <-
+      ggstatsplot::ggcorrmat(
+        data = ggplot2::msleep,
+        type = "p",
+        cor.vars = "sleep_total":"awake",
+        cor.vars.names = c("1", "2", "3", "4"),
+        p.adjust.method = "BH",
+        output = "aaa"
+      )
 
     # method 2
-    df2 <- ggstatsplot::ggcorrmat(
-      data = ggplot2::msleep,
-      cor.vars = c("sleep_total":"bodywt"),
-      p.adjust.method = "BH",
-      output = "ci"
-    )
+    set.seed(123)
+    df2 <-
+      suppressWarnings(ggstatsplot::ggcorrmat(
+        data = ggplot2::msleep,
+        type = "np",
+        cor.vars = c("sleep_total":"awake"),
+        p.adjust.method = "none",
+        output = "bbbb"
+      ))
 
     # method 3
-    df3 <- ggstatsplot::ggcorrmat(
-      data = ggplot2::msleep,
-      cor.vars = sleep_total:bodywt,
-      p.adjust.method = "BH",
-      output = "ci"
-    )
+    set.seed(123)
+    df3 <-
+      ggstatsplot::ggcorrmat(
+        data = ggplot2::msleep,
+        type = "r",
+        cor.vars = sleep_total:awake,
+        p.adjust.method = "holm",
+        output = "ci"
+      )
 
     # method 4
-    df4 <- ggstatsplot::ggcorrmat(
-      data = ggplot2::msleep,
-      cor.vars = c(sleep_total:bodywt),
-      p.adjust.method = "BH",
-      output = "ci"
-    )
+    set.seed(123)
+    df4 <-
+      suppressWarnings(ggstatsplot::ggcorrmat(
+        data = ggplot2::msleep,
+        type = "bf",
+        cor.vars = c(sleep_total:awake),
+        p.adjust.method = "fdr",
+        output = "hdhfhfh"
+      ))
 
-    # check dimensions
-    testthat::expect_equal(dim(df1), dim(df2))
-    testthat::expect_equal(dim(df3), dim(df4))
+    # check dataframes
+    testthat::expect_equal(dim(df1), c(6L, 10L))
+    testthat::expect_equal(dim(df2), c(6L, 9L))
+    testthat::expect_equal(dim(df3), c(6L, 10L))
+    testthat::expect_equal(dim(df4), c(6L, 12L))
+
+    testthat::expect_identical(unique(df1$parameter1), c("1", "2", "3"))
   }
 )
 
@@ -54,23 +70,24 @@ testthat::test_that(
 
     # creating the plot
     set.seed(123)
-    p <- ggstatsplot::ggcorrmat(
-      data = iris,
-      type = "p",
-      title = "Iris dataset",
-      subtitle = "By Edgar Anderson",
-      ggstatsplot.layer = FALSE,
-      sig.level = 0.001,
-      p.adjust.method = "fdr",
-      colors = NULL,
-      k = 4,
-      ggcorrplot.args = list(
-        lab_col = "white",
-        pch.col = "white",
-        pch.cex = 14
-      ),
-      messages = TRUE
-    )
+    p <-
+      ggstatsplot::ggcorrmat(
+        data = iris,
+        type = "p",
+        title = "Iris dataset",
+        subtitle = "By Edgar Anderson",
+        ggstatsplot.layer = FALSE,
+        sig.level = 0.001,
+        p.adjust.method = "fdr",
+        colors = NULL,
+        k = 4,
+        ggcorrplot.args = list(
+          lab_col = "white",
+          pch.col = "white",
+          pch.cex = 14
+        ),
+        messages = TRUE
+      )
 
     # checking legend title
     pb <- ggplot2::ggplot_build(p)
@@ -132,25 +149,33 @@ testthat::test_that(
     # checking plot labels
     testthat::expect_identical(p$labels$title, "Iris dataset")
     testthat::expect_identical(p$labels$subtitle, "By Edgar Anderson")
-    testthat::expect_identical(p_legend_title, ggplot2::expr(atop(
-      atop(scriptstyle(bold("sample size:")), italic(n) ~
-      "=" ~ 150L),
-      atop(
-        scriptstyle(bold("correlation:")),
-        "Pearson"
-      )
-    )))
-    testthat::expect_identical(p$labels$caption, ggplot2::expr(atop(
-      expr = paste(
-        bold("X"),
-        " = correlation non-significant at ",
-        italic("p"),
-        " < ",
-        0.001,
-        sep = ""
-      ),
-      "Adjustment (p-value): Benjamini & Hochberg"
-    )))
+    testthat::expect_identical(
+      p_legend_title,
+      ggplot2::expr(atop(
+        atop(scriptstyle(bold("sample size:")), italic(n) ~
+        "=" ~ 150L),
+        atop(
+          scriptstyle(bold("correlation:")),
+          "Pearson"
+        )
+      ))
+    )
+    testthat::expect_identical(
+      p$labels$caption,
+      ggplot2::expr(atop(
+        displaystyle(NULL),
+        expr = paste(
+          bold("X"),
+          " = non-significant at ",
+          italic("p"),
+          " < ",
+          0.001,
+          " (Adjustment: ",
+          "Benjamini & Hochberg",
+          ")"
+        )
+      ))
+    )
     testthat::expect_null(p$labels$xlab, NULL)
     testthat::expect_null(p$labels$ylab, NULL)
 
@@ -173,23 +198,6 @@ testthat::test_that(
     testthat::expect_equal(pb$data[[3]]$size[1], 14L)
     testthat::expect_identical(pb$data[[2]]$colour[1], "white")
     testthat::expect_identical(pb$data[[3]]$colour[1], "white")
-
-    # checking if correlation variable names are being read properly
-    set.seed(123)
-    df2 <- ggstatsplot::ggcorrmat(
-      data = ggplot2::msleep,
-      cor.vars = sleep_total:awake,
-      cor.vars.names = c("sleep (total)", "sleep (REM)", "sleep (cycle)", "awake"),
-      type = "r",
-      output = "p",
-      p.adjust.method = "fdr",
-      messages = FALSE
-    )
-
-    testthat::expect_identical(
-      df2$variable,
-      c("sleep (total)", "sleep (REM)", "sleep (cycle)", "awake")
-    )
   }
 )
 
@@ -202,15 +210,16 @@ testthat::test_that(
 
     # creating the plot
     set.seed(123)
-    p <- ggstatsplot::ggcorrmat(
-      data = ggplot2::msleep,
-      type = "r",
-      sig.level = 0.01,
-      p.adjust.method = "hommel",
-      matrix.type = "upper",
-      caption.default = FALSE,
-      messages = FALSE
-    )
+    p <-
+      ggstatsplot::ggcorrmat(
+        data = ggplot2::msleep,
+        type = "r",
+        sig.level = 0.01,
+        p.adjust.method = "hommel",
+        matrix.type = "upper",
+        messages = FALSE
+      ) +
+      labs(caption = NULL)
 
     # checking legend title
     pb <- ggplot2::ggplot_build(p)
@@ -231,7 +240,6 @@ testthat::test_that(
     testthat::expect_equal(data_dims, c(15L, 7L))
     testthat::expect_equal(dim(pb$data[[1]]), c(15L, 15L))
     testthat::expect_equal(dim(pb$data[[2]]), c(15L, 15L))
-    testthat::expect_equal(dim(pb$data[[3]]), c(1L, 10L))
     testthat::expect_equal(length(pb$data), 3L)
     testthat::expect_equal(
       dat$coef,
@@ -258,7 +266,7 @@ testthat::test_that(
     testthat::expect_equal(dat$Var2[4], "awake")
     testthat::expect_equal(
       dat$signif,
-      c(1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1)
+      c(1, 1, 0, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1)
     )
     testthat::expect_identical(
       p$plot_env$colors,
@@ -266,24 +274,22 @@ testthat::test_that(
     )
 
     # checking plot labels
-    testthat::expect_null(p$labels$title, NULL)
-    testthat::expect_null(p$labels$subtitle, NULL)
-    testthat::expect_null(p$labels$caption, NULL)
-    testthat::expect_null(p$labels$xlab, NULL)
-    testthat::expect_null(p$labels$ylab, NULL)
-    testthat::expect_identical(p_legend_title, ggplot2::expr(atop(
-      atop(
+    testthat::expect_identical(
+      p_legend_title,
+      ggplot2::expr(atop(atop(
         atop(scriptstyle(bold("sample size:")), italic(n)[min] ~
-        "=" ~ 30),
+        "=" ~ 30L),
         atop(
-          italic(n)[median] ~ "=" ~ 56,
-          italic(n)[max] ~ "=" ~ 83
+          italic(n)[mode] ~ "=" ~ 32L,
+          italic(n)[max] ~ "=" ~ 83L
         )
       ), atop(
-        scriptstyle(bold("correlation:")),
+        scriptstyle(
+          bold("correlation:")
+        ),
         "robust (% bend)"
-      )
-    )))
+      )))
+    )
 
     # check if number of cells is *not* equal to number of correlations
     testthat::expect_false(
@@ -301,18 +307,20 @@ testthat::test_that(
 
     # creating the plot
     set.seed(123)
-    p <- ggstatsplot::ggcorrmat(
-      data = ggplot2::msleep,
-      cor.vars = sleep_total:awake,
-      type = "np",
-      sig.level = 0.01,
-      p.adjust.method = "hommel",
-      caption.default = FALSE,
-      messages = FALSE,
-      colors = NULL,
-      package = "wesanderson",
-      palette = "Rushmore1"
-    )
+    p <-
+      suppressWarnings(ggstatsplot::ggcorrmat(
+        data = ggplot2::msleep,
+        cor.vars = sleep_total:awake,
+        cor.vars.names = "sleep_total",
+        type = "np",
+        sig.level = 0.01,
+        p.adjust.method = "hommel",
+        caption.default = FALSE,
+        messages = FALSE,
+        colors = NULL,
+        package = "wesanderson",
+        palette = "Rushmore1"
+      ))
 
     # checking legend title
     pb <- ggplot2::ggplot_build(p)
@@ -341,188 +349,28 @@ testthat::test_that(
     testthat::expect_equal(dat$signif[7], 0L)
     testthat::expect_equal(dat$signif[10], 0L)
     testthat::expect_equal(dat$signif[11], 1L)
+
+    # checking aesthetics
     testthat::expect_identical(
-      unclass(p$plot_env$colors),
-      c("#E1BD6DFF", "#EABE94FF", "#0B775EFF")
-    )
-    testthat::expect_identical(p_legend_title, ggplot2::expr(atop(atop(
-      atop(scriptstyle(bold("sample size:")), italic(n)[min] ~
-      "=" ~ 32),
-      atop(
-        italic(n)[median] ~ "=" ~ 61,
-        italic(n)[max] ~ "=" ~ 83
-      )
-    ), atop(
-      scriptstyle(
-        bold("correlation:")
-      ),
-      "Spearman"
-    ))))
-  }
-)
-
-# checking sample sizes ---------------------------------------------------
-
-testthat::test_that(
-  desc = "checking sample sizes",
-  code = {
-    testthat::skip_on_cran()
-
-    # dataframe with sample sizes
-    set.seed(123)
-    df <- ggstatsplot::ggcorrmat(
-      data = ggplot2::msleep,
-      cor.vars = sleep_total:awake,
-      type = "r",
-      output = "n",
-      p.adjust.method = "fdr",
-      messages = FALSE
+      unique(pb$data[[1]]$fill),
+      c("#0B775E", "#57896B", "#E6BE81", "#E1BD6D", "#E7BE87", "#E3BD77", "#8E9C79")
     )
 
     testthat::expect_identical(
-      df$variable,
-      c("sleep_total", "sleep_rem", "sleep_cycle", "awake")
-    )
-    testthat::expect_equal(df$sleep_total, c(83L, 61L, 32L, 83L))
-    testthat::expect_equal(df$sleep_rem, c(61L, 61L, 32L, 61L))
-    testthat::expect_equal(df$sleep_cycle, c(32L, 32L, 32L, 32L))
-    testthat::expect_equal(df$awake, c(83L, 61L, 32L, 83L))
-    testthat::expect_true(inherits(df, what = "tbl_df"))
-  }
-)
-
-# checking p-values ---------------------------------------------------
-
-testthat::test_that(
-  desc = "checking p-values",
-  code = {
-    testthat::skip_on_cran()
-
-    # dataframe with sample sizes
-    set.seed(123)
-    df <- ggstatsplot::ggcorrmat(
-      data = ggplot2::msleep,
-      cor.vars = sleep_total:awake,
-      type = "np",
-      output = "p",
-      p.adjust.method = "none",
-      messages = FALSE
-    )
-
-    testthat::expect_equal(df$sleep_cycle[1], 0.00453, tolerance = 0.001)
-    testthat::expect_equal(df$sleep_cycle[2], 0.0614, tolerance = 0.001)
-    testthat::expect_true(inherits(df, what = "tbl_df"))
-  }
-)
-
-# checking confidence intervals ----------------------------------------------
-
-testthat::test_that(
-  desc = "checking confidence intervals",
-  code = {
-    testthat::skip_on_cran()
-
-    # dataframe with sample sizes
-    set.seed(123)
-    df <- ggstatsplot::ggcorrmat(
-      data = ggplot2::msleep,
-      cor.vars = sleep_total:awake,
-      type = "p",
-      output = "ci",
-      p.adjust.method = "none",
-      messages = FALSE
-    )
-
-    testthat::expect_true(inherits(df, what = "tbl_df"))
-    testthat::expect_identical(
-      df$pair,
-      c(
-        "sleep_total-sleep_rem",
-        "sleep_total-sleep_cycle",
-        "sleep_total-awake",
-        "sleep_rem-sleep_cycle",
-        "sleep_rem-awake",
-        "sleep_cycle-awake"
-      )
-    )
-    testthat::expect_equal(
-      df$r,
-      c(
-        0.7517550,
-        -0.4737127,
-        -0.9999986,
-        -0.3381235,
-        -0.7517713,
-        0.4737127
-      ),
-      tolerance = 0.001
-    )
-    testthat::expect_equal(
-      df$lower,
-      c(
-        0.6166756,
-        -0.7058189,
-        -0.9999991,
-        -0.6143809,
-        -0.8438428,
-        0.1497554
-      ),
-      tolerance = 0.001
-    )
-    testthat::expect_equal(
-      df$upper,
-      c(
-        0.84383201,
-        -0.14975542,
-        -0.99999779,
-        0.01198335,
-        -0.61669876,
-        0.70581894
-      ),
-      tolerance = 0.001
-    )
-  }
-)
-
-# checking messages -------------------------------------------------------
-
-testthat::test_that(
-  desc = "checking messages",
-  code = {
-    testthat::skip_on_cran()
-
-    # capturing the message
-    set.seed(123)
-    testthat::expect_error(ggstatsplot::ggcorrmat(
-      data = ggplot2::msleep,
-      cor.vars = sleep_total:awake,
-      type = "r",
-      output = "ci",
-      cor.vars.names = "awake",
-      sig.level = 0.01,
-      p.adjust.method = "hommel",
-      caption.default = FALSE,
-      messages = TRUE
-    ))
-
-    p_message2 <-
-      capture.output(ggstatsplot::ggcorrmat(
-        data = ggplot2::msleep,
-        cor.vars = sleep_total:awake,
-        output = "p",
-        p.adjust.method = "hommel",
-        caption.default = FALSE,
-        messages = TRUE
-      ))
-
-    # checking messages
-    testthat::expect_match(
-      p_message2[2],
-      "the upper triangle: p-values adjusted for multiple comparisons"
-    )
-    testthat::expect_match(
-      p_message2[3],
-      "the lower triangle: unadjusted p-values"
+      p_legend_title,
+      ggplot2::expr(atop(atop(
+        atop(scriptstyle(bold("sample size:")), italic(n)[min] ~
+        "=" ~ 32L),
+        atop(
+          italic(n)[mode] ~ "=" ~ 32L,
+          italic(n)[max] ~ "=" ~ 83L
+        )
+      ), atop(
+        scriptstyle(
+          bold("correlation:")
+        ),
+        "Spearman"
+      )))
     )
   }
 )
